@@ -215,8 +215,8 @@ class DXFBase(object):
         def make_kwargs():
             r = {'allow_redirects': True, 'verify': self._tlsverify, 'timeout': self._timeout}
             r.update(kwargs)
-            if 'headers' not in r:
-                r['headers'] = {}
+            r['headers'] = {}
+            r['headers'].update(kwargs.get('headers', {}))
             r['headers'].update(self._headers)
             return r
         url = urlparse.urljoin(self._base_url, path)
@@ -429,7 +429,8 @@ class DXF(DXFBase):
                 return dgst
             except requests.exceptions.HTTPError as ex:
                 # pylint: disable=no-member
-                if ex.response.status_code != requests.codes.not_found:
+                if ex.response is None or \
+                   ex.response.status_code != requests.codes.not_found:
                     raise
         r = self._request('post', 'blobs/uploads/')
         upload_url = r.headers['Location']
@@ -464,7 +465,7 @@ class DXF(DXFBase):
         if chunk_size is None:
             chunk_size = 8192
         r = self._request('get', 'blobs/' + digest, stream=True)
-        class Chunks(object):
+        class Chunks(Iterable[_binary_type]):
             # pylint: disable=too-few-public-methods
             def __iter__(self):
                 sha256 = hashlib.sha256()
@@ -571,7 +572,8 @@ class DXF(DXFBase):
             return manifest_json
         except requests.exceptions.HTTPError as ex:
             # pylint: disable=no-member
-            if ex.response.status_code != requests.codes.bad_request:
+            if ex.response is None or \
+               ex.response.status_code != requests.codes.bad_request:
                 raise
             manifest_json = self.make_unsigned_manifest(alias, *digests)
             signed_json = _sign_manifest(manifest_json)
@@ -602,18 +604,7 @@ class DXF(DXFBase):
                           headers=_accept_header)
         return r.content.decode('utf-8'), r
 
-    def get_manifest(self, alias: str) -> str:
-        """
-        Get the manifest for an alias
-
-        :param alias: Alias name.
-
-        :returns: The manifest as string (JSON)
-        """
-        manifest, _ = self.get_manifest_and_response(alias)
-        return manifest
-
-    def _get_alias(self, alias, manifest, verify, sizes, get_digest, get_dcd, platform, ml):
+    def _get_alias(self, alias, manifest, verify, sizes, get_digest, get_dcd, get_manifest, platform, ml):
         # pylint: disable=too-many-arguments,too-many-locals,too-many-branches,too-many-statements
         if alias:
             manifest, r = self.get_manifest_and_response(alias)
@@ -639,7 +630,10 @@ class DXF(DXFBase):
                                  get_dcd)
             if get_dcd:
                 r, dcd = r
-            r = [(dgst, self.blob_size(dgst)) for dgst in r] if sizes else r
+            if get_manifest:
+                r = manifest
+            else:
+                r = [(dgst, self.blob_size(dgst)) for dgst in r] if sizes else r
             return (r, dcd) if get_dcd else r
 
         if content is not None:
@@ -659,7 +653,9 @@ class DXF(DXFBase):
 
         if parsed_manifest['mediaType'] == _schema2_mimetype or \
            parsed_manifest['mediaType'] == _ociv1_manifest_mimetype:
-            if get_digest:
+            if get_manifest:
+                r = manifest
+            elif get_digest:
                 r = parsed_manifest['config']['digest']
                 split_digest(r)
             else:
@@ -680,7 +676,7 @@ class DXF(DXFBase):
                     if get_dcd:
                         r[name] = entry['digest']
                     else:
-                        r[name] = self._get_alias(entry['digest'], None, verify, sizes, get_digest, get_dcd, platform, False)
+                        r[name] = self._get_alias(entry['digest'], None, verify, sizes, get_digest, get_dcd, get_manifest, platform, False)
                 if platform and name == platform:
                     r = r[name]
                     break
@@ -692,6 +688,18 @@ class DXF(DXFBase):
 
         return (r, dcd) if get_dcd else r
 
+    def get_manifest(self, alias: str, platform: Optional[str]=None) -> Union[str, Dict[str, str]]:
+        """
+        Get the manifest for an alias
+
+        :param alias: Alias name.
+
+        :param platform: For multi-arch aliases, return the information for this platform only.
+
+        :returns: The manifest as a string (JSON). For multi-arch aliases, a dict of manifest per platform.
+        """
+        return self._get_alias(alias, None, True, False, False, False, True, platform, True)
+
     def get_alias(self,
             alias: Optional[str]=None,
             manifest: Optional[str]=None,
@@ -717,7 +725,7 @@ class DXF(DXFBase):
 
         :returns: If ``sizes`` is falsey, a list of blob hashes (strings) which are assigned to the alias. If ``sizes`` is truthy, a list of (hash,size) tuples for each blob. For multi-arch aliases, a dict of the same per platform.
         """
-        return self._get_alias(alias, manifest, verify, sizes, False, False, platform, True)
+        return self._get_alias(alias, manifest, verify, sizes, False, False, False, platform, True)
 
     def get_digest(self,
             alias: Optional[str]=None,
@@ -740,7 +748,7 @@ class DXF(DXFBase):
 
         :returns: Hash of the alias's configuration blob. For multi-arch aliases, a dict of the same per platform.
         """
-        return self._get_alias(alias, manifest, True, False, True, False, platform, True)
+        return self._get_alias(alias, manifest, True, False, True, False, False, platform, True)
 
     def del_alias(self, alias: str) -> Union[List[str], Dict[str, str]]:
         """
@@ -754,7 +762,7 @@ class DXF(DXFBase):
 
         :returns: A list of blob hashes (strings) which were assigned to the alias. For multi-arch aliases, a dict with the alias hash per platform. You'll need to call :meth:`DXF.del_alias` for each of those.
         """
-        dgsts, dcd = self._get_alias(alias, None, True, False, False, True, None, True)
+        dgsts, dcd = self._get_alias(alias, None, True, False, False, True, False, None, True)
         self._request('delete', 'manifests/{}'.format(dcd))
         return dgsts
 
